@@ -1,5 +1,8 @@
 from stackifyapm.instrumentation.packages.base import AbstractInstrumentedModule
-from stackifyapm.traces import CaptureSpan, DroppedSpan
+from stackifyapm.traces import CaptureSpan
+from stackifyapm.traces import DroppedSpan
+from stackifyapm.traces import get_transaction
+from stackifyapm.utils.helper import is_async_span
 
 
 class UrllibInstrumentation(AbstractInstrumentedModule):
@@ -21,7 +24,7 @@ class UrllibInstrumentation(AbstractInstrumentedModule):
             "url": url,
         }
 
-        with CaptureSpan(signature, "ext.http.urllib", extra_data, leaf=True) as span:
+        with CaptureSpan(signature, "ext.http.urllib", extra_data, leaf=True, is_async=is_async_span()) as span:
             request = wrapped(*args, **kwargs)
 
             if not isinstance(span, DroppedSpan):
@@ -29,4 +32,7 @@ class UrllibInstrumentation(AbstractInstrumentedModule):
                 if hasattr(request, '_method'):
                     span.context['request_method'] = request._method
 
+                transaction = get_transaction()
+                transaction.update_span_context(span.id, span.context)
+
             return request
